@@ -20,6 +20,7 @@
 #include "kmkernel.h"
 #include "util.h"
 #include "kmail_debug.h"
+#include "job/dndfromarkjob.h"
 
 #include <qmenu.h>
 #include <KToggleAction>
@@ -79,6 +80,10 @@ bool KMComposerEditorNg::canInsertFromMimeData(const QMimeData *source) const
         return true;
     }
 
+    if (DndFromArkJob::dndFromArk(source)) {
+        return true;
+    }
+
     return MessageComposer::RichTextComposerNg::canInsertFromMimeData(source);
 }
 
@@ -150,9 +155,10 @@ void KMComposerEditorNg::showSpellConfigDialog(const QString &configFileName)
     delete dialog;
 }
 
-bool KMComposerEditorNg::convertPlainText(MessageComposer::TextPart *textPart)
+MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus KMComposerEditorNg::convertPlainText(MessageComposer::TextPart *textPart)
 {
-    Q_UNUSED(textPart);
-    //TODO implement it
-    return false;
+    if (mComposerWin->convertPlainText(textPart) == MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::Converted) {
+        return MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::Converted;
+    }
+    return MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::NotConverted;
 }
