@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -52,7 +52,16 @@ void KMailPluginEditorInitManagerInterface::initializePlugins()
 {
     if (mWasInitialized) {
         qCDebug(KMAIL_LOG) << "KMailPluginEditorInitManagerInterface : Plugin was already initialized. This is a bug";
+        return;
     }
+    if (!mRichTextEditor) {
+        qCDebug(KMAIL_LOG) << "KMailPluginEditorInitManagerInterface : Richtexteditor is null. This is a bug";
+        return;
+    }
+    if (!mParentWidget) {
+        qCDebug(KMAIL_LOG) << "KMailPluginEditorInitManagerInterface : Parent is null. This is a bug";
+    }
+
     const QVector<MessageComposer::PluginEditorInit *> lstPlugin = MessageComposer::PluginEditorInitManager::self()->pluginsList();
     for (MessageComposer::PluginEditorInit *plugin : lstPlugin) {
         if (plugin->isEnabled()) {
