@@ -6,7 +6,7 @@
     copyright            : (C) 2001 by Ryan Breen
     email                : ryan@porivo.com
 
-    Copyright (c) 2010-2017 Montel Laurent <montel@kde.org>
+    Copyright (c) 2010-2018 Montel Laurent <montel@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -20,6 +20,7 @@
 
 #include "kmsystemtray.h"
 #include "kmmainwidget.h"
+#include "unityservicemanager.h"
 #include "settings/kmailsettings.h"
 #include "mailcommon/mailutil.h"
 #include "MailCommon/MailKernel"
@@ -32,11 +33,8 @@
 #include <QMenu>
 #include <KLocalizedString>
 #include <QAction>
-#include "widgets/kactionmenutransport.h"
 
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiCore/EntityMimeTypeFilterModel>
+#include "widgets/kactionmenutransport.h"
 
 using namespace MailCommon;
 
@@ -72,15 +70,6 @@ KMSystemTray::KMSystemTray(QObject *parent)
     connect(this, &KMSystemTray::activateRequested, this, &KMSystemTray::slotActivated);
     connect(contextMenu(), &QMenu::aboutToShow,
             this, &KMSystemTray::slotContextMenuAboutToShow);
-
-    connect(kmkernel->folderCollectionMonitor(), &Akonadi::Monitor::collectionStatisticsChanged, this, &KMSystemTray::slotCollectionStatisticsChanged);
-
-    connect(kmkernel->folderCollectionMonitor(), &Akonadi::Monitor::collectionAdded, this, &KMSystemTray::initListOfCollection);
-    connect(kmkernel->folderCollectionMonitor(), &Akonadi::Monitor::collectionRemoved, this, &KMSystemTray::initListOfCollection);
-    connect(kmkernel->folderCollectionMonitor(), &Akonadi::Monitor::collectionSubscribed, this, &KMSystemTray::initListOfCollection);
-    connect(kmkernel->folderCollectionMonitor(), &Akonadi::Monitor::collectionUnsubscribed, this, &KMSystemTray::initListOfCollection);
-
-    initListOfCollection();
 }
 
 bool KMSystemTray::buildPopupMenu()
@@ -132,9 +121,11 @@ KMSystemTray::~KMSystemTray()
 {
 }
 
-void KMSystemTray::slotGeneralFontChanged()
+void KMSystemTray::initialize(int count)
 {
-    updateSystemTray();
+    updateCount(count);
+    updateStatus(count);
+    updateToolTip(count);
 }
 
 /**
@@ -142,21 +133,18 @@ void KMSystemTray::slotGeneralFontChanged()
  * show the "unread new mail" KMail icon.
  * If there is no unread mail, restore the normal KMail icon.
  */
-void KMSystemTray::updateCount()
+void KMSystemTray::updateCount(int count)
 {
-    if (mCount == 0) {
+    if (count == 0) {
         setIconByName(QStringLiteral("kmail"));
     } else {
         setIconByName(QStringLiteral("mail-mark-unread-new"));
     }
 }
 
-void KMSystemTray::setSystrayIconNotificationsEnabled(bool enabled)
+void KMSystemTray::setUnityServiceManager(UnityServiceManager *unityServiceManager)
 {
-    if (enabled != mIconNotificationsEnabled) {
-        mIconNotificationsEnabled = enabled;
-        updateSystemTray();
-    }
+    mUnityServiceManager = unityServiceManager;
 }
 
 /**
@@ -212,12 +200,13 @@ void KMSystemTray::slotContextMenuAboutToShow()
         delete mNewMessagesPopup;
         mNewMessagesPopup = nullptr;
     }
+    mHasUnreadMessage = false;
     mNewMessagesPopup = new QMenu();
     fillFoldersMenu(mNewMessagesPopup, kmkernel->treeviewModelSelection());
 
     connect(mNewMessagesPopup, &QMenu::triggered, this, &KMSystemTray::slotSelectCollection);
 
-    if (mCount > 0) {
+    if (mHasUnreadMessage) {
         mNewMessagesPopup->setTitle(i18n("New Messages In"));
         contextMenu()->insertAction(mSendQueued, mNewMessagesPopup->menuAction());
     }
@@ -230,14 +219,14 @@ void KMSystemTray::fillFoldersMenu(QMenu *menu, const QAbstractItemModel *model,
         const QModelIndex index = model->index(row, 0, parentIndex);
         const Akonadi::Collection collection = model->data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
         qint64 count = 0;
-        if (!excludeFolder(collection)) {
+        if (!mUnityServiceManager->excludeFolder(collection)) {
             Akonadi::CollectionStatistics statistics = collection.statistics();
             count = qMax(0LL, statistics.unreadCount());
             if (count > 0) {
-                if (ignoreNewMailInFolder(collection)) {
+                if (mUnityServiceManager->ignoreNewMailInFolder(collection)) {
                     count = 0;
                 } else {
-                    mCount += count;
+                    mHasUnreadMessage = true;
                 }
             }
         }
@@ -271,57 +260,21 @@ void KMSystemTray::hideKMail()
     }
 }
 
-void KMSystemTray::initListOfCollection()
+void KMSystemTray::updateToolTip(int count)
 {
-    mCount = 0;
-    const QAbstractItemModel *model = kmkernel->collectionModel();
-    if (model->rowCount() == 0) {
-        QTimer::singleShot(1000, this, &KMSystemTray::initListOfCollection);
-        return;
-    }
-    unreadMail(model);
-
-    if (status() == KStatusNotifierItem::Passive && (mCount > 0)) {
-        setStatus(KStatusNotifierItem::Active);
-    } else if (status() == KStatusNotifierItem::Active && (mCount == 0)) {
-        setStatus(KStatusNotifierItem::Passive);
-    }
-
-    //qCDebug(KMAIL_LOG)<<" mCount :"<<mCount;
-    updateCount();
-}
-
-void KMSystemTray::unreadMail(const QAbstractItemModel *model, const QModelIndex &parentIndex)
-{
-    const int rowCount = model->rowCount(parentIndex);
-    for (int row = 0; row < rowCount; ++row) {
-        const QModelIndex index = model->index(row, 0, parentIndex);
-        const Akonadi::Collection collection = model->data(index, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-
-        if (!excludeFolder(collection)) {
-            const Akonadi::CollectionStatistics statistics = collection.statistics();
-            const qint64 count = qMax(0LL, statistics.unreadCount());
-
-            if (count > 0) {
-                if (!ignoreNewMailInFolder(collection)) {
-                    mCount += count;
-                }
-            }
-        }
-        if (model->rowCount(index) > 0) {
-            unreadMail(model, index);
-        }
-    }
-    // Update tooltip to reflect count of unread messages
-    setToolTipSubTitle(mCount == 0 ? i18n("There are no unread messages")
+    setToolTipSubTitle(count == 0 ? i18n("There are no unread messages")
                        : i18np("1 unread message",
                                "%1 unread messages",
-                               mCount));
+                               count));
 }
 
-bool KMSystemTray::hasUnreadMail() const
+void KMSystemTray::updateStatus(int count)
 {
-    return mCount != 0;
+    if (status() == KStatusNotifierItem::Passive && (count > 0)) {
+        setStatus(KStatusNotifierItem::Active);
+    } else if (status() == KStatusNotifierItem::Active && (count == 0)) {
+        setStatus(KStatusNotifierItem::Passive);
+    }
 }
 
 void KMSystemTray::slotSelectCollection(QAction *act)
@@ -337,51 +290,3 @@ void KMSystemTray::slotSelectCollection(QAction *act)
         activate();
     }
 }
-
-void KMSystemTray::updateSystemTray()
-{
-    initListOfCollection();
-}
-
-void KMSystemTray::slotCollectionStatisticsChanged(Akonadi::Collection::Id id, const Akonadi::CollectionStatistics &)
-{
-    //Exclude sent mail folder
-
-    if (CommonKernel->outboxCollectionFolder().id() == id
-        || CommonKernel->sentCollectionFolder().id() == id
-        || CommonKernel->templatesCollectionFolder().id() == id
-        || CommonKernel->trashCollectionFolder().id() == id
-        || CommonKernel->draftsCollectionFolder().id() == id) {
-        return;
-    }
-    initListOfCollection();
-}
-
-bool KMSystemTray::excludeFolder(const Akonadi::Collection &collection) const
-{
-    if (!collection.isValid() || !collection.contentMimeTypes().contains(KMime::Message::mimeType())) {
-        return true;
-    }
-    if (CommonKernel->outboxCollectionFolder() == collection
-        || CommonKernel->sentCollectionFolder() == collection
-        || CommonKernel->templatesCollectionFolder() == collection
-        || CommonKernel->trashCollectionFolder() == collection
-        || CommonKernel->draftsCollectionFolder() == collection) {
-        return true;
-    }
-
-    if (MailCommon::Util::isVirtualCollection(collection)) {
-        return true;
-    }
-    return false;
-}
-
-bool KMSystemTray::ignoreNewMailInFolder(const Akonadi::Collection &collection)
-{
-    if (collection.hasAttribute<Akonadi::NewMailNotifierAttribute>()) {
-        if (collection.attribute<Akonadi::NewMailNotifierAttribute>()->ignoreNewMail()) {
-            return true;
-        }
-    }
-    return false;
-}
