@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ static QString toolTip(const Akonadi::Item &item)
 int KMSearchMessageModel::columnCount(const QModelIndex &parent) const
 {
     if (collection().isValid()
-        && !collection().contentMimeTypes().contains(QStringLiteral("message/rfc822"))
+        && !collection().contentMimeTypes().contains(QLatin1String("message/rfc822"))
         && collection().contentMimeTypes() != QStringList(QStringLiteral("inode/directory"))) {
         return 1;
     }
@@ -158,7 +158,7 @@ QVariant KMSearchMessageModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    if (!collection().contentMimeTypes().contains(QStringLiteral("message/rfc822"))) {
+    if (!collection().contentMimeTypes().contains(QLatin1String("message/rfc822"))) {
         if (role == Qt::DisplayRole) {
             return i18nc("@label", "This model can only handle email folders. The current collection holds mimetypes: %1",
                          collection().contentMimeTypes().join(QLatin1Char(',')));
@@ -224,7 +224,7 @@ QVariant KMSearchMessageModel::data(const QModelIndex &index, int role) const
 QVariant KMSearchMessageModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (collection().isValid()
-        && !collection().contentMimeTypes().contains(QStringLiteral("message/rfc822"))
+        && !collection().contentMimeTypes().contains(QLatin1String("message/rfc822"))
         && collection().contentMimeTypes() != QStringList(QStringLiteral("inode/directory"))) {
         return QVariant();
     }
